//###########################################################################
//
// FILE:	DSP281x_Ev.c
//
// TITLE:	DSP281x Event Manager Initialization & Support Functions.
//
//###########################################################################
//
//  Ver | dd mmm yyyy | Who  | Description of changes
// =====|=============|======|===============================================
//  1.00| 11 Sep 2003 | L.H. | No change since previous version (v.58 Alpha)
//###########################################################################

#include "DSP281x_Device.h"     // DSP281x Headerfile Include File
#include "DSP281x_Setting.h"   // DSP281x Examples Include File

//#pragma CODE_SECTION(EvaTimer1_Isr, "ramfuncs");
//#pragma CODE_SECTION(EvaTimer2_Isr, "ramfuncs"); 
#pragma CODE_SECTION(EvbTimer3_Isr, "ramfuncs");
#pragma CODE_SECTION(EvaCap1_Isr, "ramfuncs");
#pragma CODE_SECTION(EvaCap2_Isr, "ramfuncs");
#pragma CODE_SECTION(EvaCap3_Isr, "ramfuncs");


//---------------------------------------------------------------------------
// InitEv: 
//---------------------------------------------------------------------------
// This function initializes EVA Timer1 to a known state.
//
void InitEva_Timer1(void)
{
    // Initialize EVA Timer 1:
    // Setup Timer 1 Registers (EV A)
    EvaRegs.GPTCONA.all = 0;
   
    // Set the Period for the GP timer 1, HSPCLK=SYSCLK=120MHZ
    EvaRegs.T1PR = 29;       	 // Set ADS8365 Clock to 4Hz,30 
    EvaRegs.T1CMPR = 0x0000;     // Compare Reg
   
    // Enable Period interrupt bits for GP timer 1
    // Count up, x128, internal clk, enable compare, use own period
//  EvaRegs.EVAIMRA.bit.T1PINT = 1;
//  EvaRegs.EVAIFRA.bit.T1PINT = 1;

    // Clear the counter for GP timer 1
    EvaRegs.T1CNT = 0x0000;
    EvaRegs.T1CON.all = 0x1040;		// Continuous-Up Count Mode

    // Start EVA ADC Conversion on timer 1 Period interrupt
//    EvaRegs.GPTCONA.bit.T1TOADC = 2;
	
	EvaRegs.ACTRA.all = 0x0001;		// PWM1 Active Low
	EvaRegs.CMPR1 = 15;				// 50% Duty
	EvaRegs.DBTCONA.all = 0;		// No Deadband
	EvaRegs.COMCONA.all = 0x8220;	// Enable PWM Output

//	EvaRegs.EVAIFRA.all = 0x0FFFF;	// Clear Flag
//	EvaRegs.EVAIMRA.all = 0x0080;	// Enable T1PINT

// Enable Cap1, Cap2, Cap3, and select timer2 for Cap1, Cap2, Cap3
// Enable Falling edge for Cap1, Cap2, Cap3	
	EvaRegs.CAPCONA.all = 0x70A8;	
	EvaRegs.CAPFIFOA.all = 0x0000;

	EvaRegs.EVAIFRC.all = 0x0FFFF;	// Clear Cap Flag
	EvaRegs.EVAIMRC.all = 0x00007;	// Enable Cap1, Cap2, Cap3 Interrupt 
}

void InitEva_Timer2(void)
{
    // Initialize EVA Timer 2:
    // Setup Timer 2 Registers (EV A)
    EvaRegs.GPTCONA.all = 0;
   
    // Set the Period for the GP timer 2 to 0x0200;
    EvaRegs.T2PR = 30*40;        // 4MHz/40=100KHz
    EvaRegs.T2CMPR = 0x0000;     // Compare Reg
   
    // Enable Period interrupt bits for GP timer 2
    // Count up, x128, internal clk, enable compare, use own period
//   EvaRegs.EVAIMRB.bit.T2PINT = 1;
//   EvaRegs.EVAIFRB.bit.T2PINT = 1;

    // Clear the counter for GP timer 2
    EvaRegs.T2CNT = 0x0000;
    EvaRegs.T2CON.all = 0x1040;		// Continuous-Up Count Mode

    // Start EVA ADC Conversion on timer 2 Period interrupt
//    EvaRegs.GPTCONA.bit.T2TOADC = 2;

	EvaRegs.EVAIFRB.all = 0x0FFFF;	// Clear Flag
	EvaRegs.EVAIMRB.all = 0x0001;	// Enable T2PINT
}

void InitEvb_Timer3(void)
{
    // Initialize EVB Timer 3:
    // Setup Timer 3 Registers (EV B)
    EvbRegs.GPTCONB.all = 0;
   
    // Set the Period for the GP timer 3 to 0x0200;
    EvbRegs.T3PR = ADS8365_SAMPLE_FREQ;		// 4800 Samples/Second (96Point/20ms(50Hz))
    EvbRegs.T3CMPR = 0x0000;     		// Compare Reg
   
    // Enable Period interrupt bits for GP timer 3
    // Count up, x128, internal clk, enable compare, use own period
//    EvbRegs.EVBIMRA.bit.T3PINT = 1;
//    EvbRegs.EVBIFRA.bit.T3PINT = 1;

    // Clear the counter for GP timer 3
    EvbRegs.T3CNT = 0x0000;
    EvbRegs.T3CON.all = 0x1040;

    // Start EVA ADC Conversion on timer 3 Period interrupt
//    EvbRegs.GPTCONB.bit.T3TOADC = 2;

	//
	EvbRegs.ACTRB.all = 0x0111;				// PWM7, PWM9, PWM11 Active Low
	EvbRegs.CMPR4 = ADS8365_SAMPLE_FREQ_D;	//50%, Low Active to Hold ADS8365
	EvbRegs.CMPR5 = ADS8365_SAMPLE_FREQ_D;	//50%, Low Active to Hold ADS8365
	EvbRegs.CMPR6 = ADS8365_SAMPLE_FREQ_D;	//50%, Low Active to Hold ADS8365

	EvbRegs.COMCONB.all = 0x8220;
	EvbRegs.DBTCONB.all = 0x0000;		// Disable Deadband

	EvbRegs.EVBIFRA.all = 0x0FFFF;		// Clear Flag
	EvbRegs.EVBIMRA.all = 0x0080;		// Enable T3PINT
}

// This function initializes EVA Timer1 to a known state.
//
void InitEvb_Timer4(void)
{

}	

// This function Service EVA Timer1 interrupt.
//
interrupt void EvaTimer1_Isr(void)
{       
    // Short Delay to simulate some ISR Code

    // Enable more interrupts from this timer
    EvaRegs.EVAIMRA.bit.T1PINT = 1;

    // Note: To be safe, use a mask value to write to the entire
    // EVAIFRA register.  Writing to one bit will cause a read-modify-write
    // operation that may have the result of writing 1's to clear 
    // bits other then those intended. 
    EvaRegs.EVAIFRA.all = BIT7;

    // Acknowledge interrupt to receive more interrupts from PIE group 2
    PieCtrlRegs.PIEACK.all = PIEACK_GROUP2;

}	

// This function Service EVA Timer2 interrupt.
//
interrupt void EvaTimer2_Isr(void)
{
    // Short Delay to simulate some ISR Code

    // Enable more interrupts from this timer
    EvaRegs.EVAIMRB.bit.T2PINT = 1;

   // Note: To be safe, use a mask value to write to the entire
   // EVAIFRB register.  Writing to one bit will cause a read-modify-write
   // operation that may have the result of writing 1's to clear 
   // bits other then those intended. 
   EvaRegs.EVAIFRB.all = BIT0;

   // Acknowledge interrupt to recieve more interrupts from PIE group 3
   PieCtrlRegs.PIEACK.all = PIEACK_GROUP3;

}	

// This function Service EVB Timer3 interrupt.
//
interrupt void EvbTimer3_Isr(void)
{
    // Short Delay to simulate some ISR Code

#if	CAPINT_MODE == SET_YES
	if(ADC_EOC_Flag[ADS8365_U2] == 1)
	{
		EvaRegs.CAPFIFOA.bit.CAP1FIFO = 0;
    	EvaRegs.EVAIFRC.bit.CAP1INT = 1;
		ADC_EOC_Flag[ADS8365_U2] = 0;

		read_ADS8365(ADS8365_U2);
		GpioDataRegs.GPATOGGLE.bit.GPIOA5 = 1;	// A3 Toggle
	}

	if(ADC_EOC_Flag[ADS8365_U3] == 1)
	{
		EvaRegs.CAPFIFOA.bit.CAP2FIFO = 0;
    	EvaRegs.EVAIFRC.bit.CAP2INT = 1;
		ADC_EOC_Flag[ADS8365_U3] = 0;

		read_ADS8365(ADS8365_U3);
		GpioDataRegs.GPATOGGLE.bit.GPIOA6 = 1;	// A3 Toggle
	}

	if(ADC_EOC_Flag[ADS8365_U4] == 1)
	{
		EvaRegs.CAPFIFOA.bit.CAP3FIFO = 0;
    	EvaRegs.EVAIFRC.bit.CAP3INT = 1;
		ADC_EOC_Flag[ADS8365_U4] = 0;

		read_ADS8365(ADS8365_U4);
		GpioDataRegs.GPATOGGLE.bit.GPIOA7 = 1;	// A3 Toggle
	}
#endif

#if	CAPINT_MODE == SET_NO
//	if(EvaRegs.CAPFIFOA.bit.CAP1FIFO >= 2)
//	{
#if U2_ADS8365 == AD_ENABLE
		EvaRegs.CAPFIFOA.bit.CAP1FIFO = 0;
		read_ADS8365(ADS8365_U2);
#endif

//	}

//	if(EvaRegs.CAPFIFOA.bit.CAP2FIFO >= 2)
//	{
#if U3_ADS8365 == AD_ENABLE
		EvaRegs.CAPFIFOA.bit.CAP2FIFO = 0;
		read_ADS8365(ADS8365_U3);
#endif

//	}

//	if(EvaRegs.CAPFIFOA.bit.CAP3FIFO >= 2)
//	{
#if U4_ADS8365 == AD_ENABLE
		EvaRegs.CAPFIFOA.bit.CAP3FIFO = 0;
		read_ADS8365(ADS8365_U4);
#endif
//	}
#endif

    // Note: To be safe, use a mask value to write to the entire
    // EVBIFRA register.  Writing to one bit will cause a read-modify-write
    // operation that may have the result of writing 1's to clear 
    // bits other then those intended. 
    EvbRegs.EVBIFRA.all = BIT7;

    // Acknowledge interrupt to receive more interrupts from PIE group 4
    PieCtrlRegs.PIEACK.all = PIEACK_GROUP4;

}	


// This function Service EVA Cap1 interrupt.
//
interrupt void EvaCap1_Isr(void)
{       
    // Short Delay to simulate some ISR Code
	if(ADC_EOC_Flag[ADS8365_U2] == 0)
	{
		ADC_EOC_Flag[ADS8365_U2] = 1;
		GpioDataRegs.GPATOGGLE.bit.GPIOA5 = 1; 	// A5 Toggle for U2
	}

    // Enable more interrupts from this timer
    EvaRegs.EVAIMRC.bit.CAP1INT = 1;

    // Note: To be safe, use a mask value to write to the entire
    // EVAIFRA register.  Writing to one bit will cause a read-modify-write
    // operation that may have the result of writing 1's to clear 
    // bits other then those intended. 
	EvaRegs.CAPFIFOA.bit.CAP1FIFO = 0;
    EvaRegs.EVAIFRC.bit.CAP1INT = 1;

    // Acknowledge interrupt to receive more interrupts from PIE group 2
    PieCtrlRegs.PIEACK.all = PIEACK_GROUP3;

}	

// This function Service EVA Cap2 interrupt.
//
interrupt void EvaCap2_Isr(void)
{       
    // Short Delay to simulate some ISR Code
	if(ADC_EOC_Flag[ADS8365_U3] == 0)
	{
		ADC_EOC_Flag[ADS8365_U3] = 1;
		GpioDataRegs.GPATOGGLE.bit.GPIOA6 = 1; 	// A6 Toggle for U2
	}

    // Enable more interrupts from this timer
    EvaRegs.EVAIMRC.bit.CAP2INT = 1;

    // Note: To be safe, use a mask value to write to the entire
    // EVAIFRA register.  Writing to one bit will cause a read-modify-write
    // operation that may have the result of writing 1's to clear 
    // bits other then those intended. 
	EvaRegs.CAPFIFOA.bit.CAP2FIFO = 0;
    EvaRegs.EVAIFRC.bit.CAP2INT = 1;

    // Acknowledge interrupt to receive more interrupts from PIE group 2
    PieCtrlRegs.PIEACK.all = PIEACK_GROUP3;

}	

// This function Service EVA Cap3 interrupt.
//
interrupt void EvaCap3_Isr(void)
{       
    // Short Delay to simulate some ISR Code
	if(ADC_EOC_Flag[ADS8365_U4] == 0)
	{
		ADC_EOC_Flag[ADS8365_U4] = 1;
		GpioDataRegs.GPATOGGLE.bit.GPIOA7 = 1; 	// A7 Toggle for U2
	}

    // Enable more interrupts from this timer
    EvaRegs.EVAIMRC.bit.CAP3INT = 1;

    // Note: To be safe, use a mask value to write to the entire
    // EVAIFRA register.  Writing to one bit will cause a read-modify-write
    // operation that may have the result of writing 1's to clear 
    // bits other then those intended. 
	EvaRegs.CAPFIFOA.bit.CAP3FIFO = 0;
    EvaRegs.EVAIFRC.bit.CAP3INT = 1;

    // Acknowledge interrupt to receive more interrupts from PIE group 2
    PieCtrlRegs.PIEACK.all = PIEACK_GROUP3;

}	
	
//===========================================================================
// No more.
//===========================================================================
