//###########################################################################
//
// FILE:	DSP281x_Gpio.c
//
// TITLE:	DSP281x General Purpose I/O Initialization & Support Functions.
//
//###########################################################################
//
//  Ver | dd mmm yyyy | Who  | Description of changes
// =====|=============|======|===============================================
//  1.00| 11 Sep 2003 | L.H. | No change since previous version (v.58 Alpha)
//###########################################################################

#include "DSP281x_Device.h"     // DSP281x Headerfile Include File
#include "DSP281x_Setting.h"   // DSP281x Examples Include File

//---------------------------------------------------------------------------
// InitGpio: 
//---------------------------------------------------------------------------
// This function initializes the Gpio to a known state.
//
void InitGpio(void)
{

// Set GPIO A port pins
// Input Qualifier =0, none
     EALLOW;
// PWM1_GPIOA0 as PWM output
// CAP1_GPIOA8 as CAP1 Input
// CAP2_GPIOA9 as CAP2 Input
// CAP3_GPIOA10 as CAP3 Input
     GpioMuxRegs.GPAMUX.all = 0x0701;	     
     GpioMuxRegs.GPADIR.all = 0xF0FC;    	// A2, A3 A4, A5, A6, A7, A12, A13, A14, A15 as output
     GpioMuxRegs.GPAQUAL.all = 0x0000;		// Input qualifier disabled
// A2 = 1(Reset=0) as output display have a bad point in U2_ADS8365 Data
// A3 = 1(Reset=0) as output display have a bad point in U3_ADS8365 Data
// A4 = 1(Reset=0) as output display have a bad point in U4_ADS8365 Data

// A5 as output toggle in in CAP1INT
// A6 as output toggle in in CAP1INT
// A7 as output toggle in in CAP1INT

// A12 = 1(Reset=0) as output display have a bad point in U2/U3/U4_ADS8365 Data

// A13 = 1(Reset=0) as output display have a bad point(=0/=1) in U2_ADS8365 Data
// A14 = 1(Reset=0) as output display have a bad point(=0/=1) in U3_ADS8365 Data
// A15 = 1(Reset=0) as output display have a bad point(=0/=1) in U4_ADS8365 Data

	 GpioDataRegs.GPADAT.all = 0x0000;		// A2=0, A3=0, A4=0, A5=1, A6=0, A7=0, A13=0, A14=0, A15=0 

// Set GPIO B port pins
// Input Qualifier =0, none
// Set bits to 1 to configure peripherals signals on the pins
// PWM7_GPIOB0 as PWM7 output for U2(ADS8365) Holdx, 
// PWM9_GPIOB2 as PWM9 output for U3(ADS8365) Holdx,
// PWM11_GPIOB4 as PWM11 output for U4(ADS8365) Holdx,
     GpioMuxRegs.GPBMUX.all = 0x0015;		
     GpioMuxRegs.GPBDIR.all = 0x0000; 
     GpioMuxRegs.GPBQUAL.all = 0x0000;		// Input qualifier disabled

// Set GPIO D port pins
// Input Qualifier =0, none
// Set bits to 1 to configure peripherals signals on the pins
     GpioMuxRegs.GPDMUX.all = 0x0000;		
     GpioMuxRegs.GPDDIR.all = 0x0000; 
     GpioMuxRegs.GPDQUAL.all = 0x0000;		// Input qualifier disabled

// Set GPIO E port pins
// Input Qualifier =0, none
// Set bits to 1 to configure peripherals signals on the pins
     GpioMuxRegs.GPEMUX.all = 0x0000;		 
     GpioMuxRegs.GPEDIR.all = 0x0000; 
     GpioMuxRegs.GPEQUAL.all = 0x0000;		// Input qualifier disabled

// Set GPIO F port pins
// Input Qualifier =0, none
// Set bits to 1 to configure peripherals signals on the pins
     GpioMuxRegs.GPFMUX.all = 0x0000;		 
     GpioMuxRegs.GPFDIR.all = 0x0000; 

// Set GPIO G port pins
// Input Qualifier =0, none
// Set bits to 1 to configure peripherals signals on the pins
     GpioMuxRegs.GPGMUX.all = 0x0000;		 
     GpioMuxRegs.GPGDIR.all = 0x0000; 

     EDIS;

}	
	
//===========================================================================
// No more.
//===========================================================================
